@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2013-2017 -- leonerd@leonerd.org.uk
 
-package Devel::MAT;
+package Devel::MAT 0.44;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.42';
-
 use Carp;
 use List::Util qw( first pairs );
 use List::UtilsBy qw( sort_by );
@@ -25,7 +23,7 @@ use Module::Pluggable
    require => 1;
 
 require XSLoader;
-XSLoader::load( __PACKAGE__, $VERSION );
+XSLoader::load( __PACKAGE__, our $VERSION );
 
 =head1 NAME
 
@@ -172,6 +170,26 @@ sub load_tool_for_command
    };
 }
 
+=head2 run_command
+
+   $pmat->run_command( $inv )
+
+Runs a tool command given by the L<Commandable::Invocation> instance.
+
+=cut
+
+sub run_command
+{
+   my $self = shift;
+   my ( $inv, %args ) = @_;
+
+   my $cmd = $inv->pull_token;
+
+   $self->load_tool_for_command( $cmd,
+      progress => $args{process},
+   )->run_cmd( $inv );
+}
+
 =head2 inref_graph
 
    $node = $pmat->inref_graph( $sv, %opts )
@@ -557,9 +575,11 @@ sub format_value
       return "[" . Devel::MAT::Cmd->_format_value( $val+0 ) . "]";
    }
    elsif( $opts{pv} ) {
-      my $maxlen = $opts{maxlen} // 64;
-      ( my $truncated = length $val > $maxlen ) and
-         substr( $val, $maxlen ) = "";
+      my $truncated;
+      if( my $maxlen = $opts{maxlen} // 64 ) {
+         ( $truncated = length $val > $maxlen ) and
+            substr( $val, $maxlen ) = "";
+      }
 
       return Devel::MAT::Cmd->_format_value(
          perlstring( $val ) . ( $truncated ? "..." : "" )
