@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2016-2018 -- leonerd@leonerd.org.uk
 
-package Devel::MAT::Tool;
+package Devel::MAT::Tool 0.44;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.43';
-
 use List::Util qw( any );
 use Commandable::Invocation;
 Commandable::Invocation->VERSION( '0.04' ); # ->peek_remaining
