@@ -3,14 +3,12 @@
 #
 #  (C) Paul Evans, 2013-2017 -- leonerd@leonerd.org.uk
 
-package Devel::MAT::Tool::Inrefs;
+package Devel::MAT::Tool::Inrefs 0.44;
 
-use strict;
+use v5.14;
 use warnings;
 use base qw( Devel::MAT::Tool );
 
-our $VERSION = '0.43';
-
 use List::Util qw( any pairs );
 
 my %STRENGTH_TO_IDX = (
