@@ -3,14 +3,12 @@
 #
 #  (C) Paul Evans, 2013-2017 -- leonerd@leonerd.org.uk
 
-package Devel::MAT::Tool::Sizes;
+package Devel::MAT::Tool::Sizes 0.44;
 
-use strict;
+use v5.14;
 use warnings;
 use base qw( Devel::MAT::Tool );
 
-our $VERSION = '0.42';
-
 use constant FOR_UI => 1;
 
 use List::Util qw( sum0 );
